aboutsummaryrefslogtreecommitdiff
path: root/extension/src/openvic-extension/singletons/GameSingleton.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'extension/src/openvic-extension/singletons/GameSingleton.hpp')
-rw-r--r--extension/src/openvic-extension/singletons/GameSingleton.hpp5
1 files changed, 2 insertions, 3 deletions
diff --git a/extension/src/openvic-extension/singletons/GameSingleton.hpp b/extension/src/openvic-extension/singletons/GameSingleton.hpp
index 5895899..5559f1b 100644
--- a/extension/src/openvic-extension/singletons/GameSingleton.hpp
+++ b/extension/src/openvic-extension/singletons/GameSingleton.hpp
@@ -56,9 +56,8 @@ namespace OpenVic {
static godot::String search_for_game_path(godot::String hint_path = {});
- /* Post-load/restart game setup - reset the game to post-load state
- * and (re)generate starting data, e.g. buildings. */
- godot::Error setup_game();
+ /* Post-load/restart game setup - reset the game to post-load state and load the specified bookmark. */
+ godot::Error setup_game(int32_t bookmark_index);
int32_t get_province_index_from_uv_coords(godot::Vector2 const& coords) const;